@@ -1,7 +1,7 @@
 /*
  *  be_local.c : backend for the local database
  *
- *  Copyright (c) 2006-2018 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2020 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -153,6 +153,18 @@ static alpm_list_t *_cache_get_optdepends(alpm_pkg_t *pkg)
 	return pkg->optdepends;
 }
 
+static alpm_list_t *_cache_get_makedepends(alpm_pkg_t *pkg)
+{
+	LAZY_LOAD(INFRQ_DESC);
+	return pkg->makedepends;
+}
+
+static alpm_list_t *_cache_get_checkdepends(alpm_pkg_t *pkg)
+{
+	LAZY_LOAD(INFRQ_DESC);
+	return pkg->checkdepends;
+}
+
 static alpm_list_t *_cache_get_conflicts(alpm_pkg_t *pkg)
 {
 	LAZY_LOAD(INFRQ_DESC);
@@ -303,36 +315,38 @@ static int _cache_force_load(alpm_pkg_t *pkg)
  * logic.
  */
 static struct pkg_operations local_pkg_ops = {
-	.get_base        = _cache_get_base,
-	.get_desc        = _cache_get_desc,
-	.get_url         = _cache_get_url,
-	.get_builddate   = _cache_get_builddate,
+	.get_base = _cache_get_base,
+	.get_desc = _cache_get_desc,
+	.get_url = _cache_get_url,
+	.get_builddate = _cache_get_builddate,
 	.get_installdate = _cache_get_installdate,
-	.get_packager    = _cache_get_packager,
-	.get_arch        = _cache_get_arch,
-	.get_isize       = _cache_get_isize,
-	.get_reason      = _cache_get_reason,
-	.get_validation  = _cache_get_validation,
-	.has_scriptlet   = _cache_has_scriptlet,
-	.get_licenses    = _cache_get_licenses,
-	.get_groups      = _cache_get_groups,
-	.get_depends     = _cache_get_depends,
-	.get_optdepends  = _cache_get_optdepends,
-	.get_conflicts   = _cache_get_conflicts,
-	.get_provides    = _cache_get_provides,
-	.get_replaces    = _cache_get_replaces,
-	.get_files       = _cache_get_files,
-	.get_backup      = _cache_get_backup,
+	.get_packager = _cache_get_packager,
+	.get_arch = _cache_get_arch,
+	.get_isize = _cache_get_isize,
+	.get_reason = _cache_get_reason,
+	.get_validation = _cache_get_validation,
+	.has_scriptlet = _cache_has_scriptlet,
+	.get_licenses = _cache_get_licenses,
+	.get_groups = _cache_get_groups,
+	.get_depends = _cache_get_depends,
+	.get_optdepends = _cache_get_optdepends,
+	.get_makedepends = _cache_get_makedepends,
+	.get_checkdepends = _cache_get_checkdepends,
+	.get_conflicts = _cache_get_conflicts,
+	.get_provides = _cache_get_provides,
+	.get_replaces = _cache_get_replaces,
+	.get_files = _cache_get_files,
+	.get_backup = _cache_get_backup,
 
-	.changelog_open  = _cache_changelog_open,
-	.changelog_read  = _cache_changelog_read,
+	.changelog_open = _cache_changelog_open,
+	.changelog_read = _cache_changelog_read,
 	.changelog_close = _cache_changelog_close,
 
-	.mtree_open      = _cache_mtree_open,
-	.mtree_next      = _cache_mtree_next,
-	.mtree_close     = _cache_mtree_close,
+	.mtree_open = _cache_mtree_open,
+	.mtree_next = _cache_mtree_next,
+	.mtree_close = _cache_mtree_close,
 
-	.force_load      = _cache_force_load,
+	.force_load = _cache_force_load,
 };
 
 static int checkdbdir(alpm_db_t *db)
@@ -773,6 +787,10 @@ static int local_db_read(alpm_pkg_t *info, int inforeq)
 				READ_AND_SPLITDEP(info->depends);
 			} else if(strcmp(line, "%OPTDEPENDS%") == 0) {
 				READ_AND_SPLITDEP(info->optdepends);
+			} else if(strcmp(line, "%MAKEDEPENDS%") == 0) {
+				READ_AND_SPLITDEP(info->makedepends);
+			} else if(strcmp(line, "%CHECKDEPENDS%") == 0) {
+				READ_AND_SPLITDEP(info->checkdepends);
 			} else if(strcmp(line, "%CONFLICTS%") == 0) {
 				READ_AND_SPLITDEP(info->conflicts);
 			} else if(strcmp(line, "%PROVIDES%") == 0) {
